@@ -2,7 +2,7 @@
 # The turbomoleio package, a python interface to Turbomole
 # for preparing inputs, parsing outputs and other related tools.
 #
-# Copyright (C) 2018-2021 BASF SE, Matgenix SRL.
+# Copyright (C) 2018-2022 BASF SE, Matgenix SRL.
 #
 # This file is part of turbomoleio.
 #
@@ -38,15 +38,14 @@ A complete description of the data group model of TurboMole can be found in
 the user's manual, as well as a description of all the keywords available.
 """
 
-import re
 import os
-from collections import namedtuple
+import re
 
 from monty.json import MSONable
 
 
 def cleanup_string(string, cleanup_types=None):
-    """Returns a cleaned data groups string.
+    """Return a cleaned data groups string.
 
     This function allows to clean up a data groups string. It allows to :
     - remove everything before the first dollar ("$") sign,
@@ -73,54 +72,53 @@ def cleanup_string(string, cleanup_types=None):
             is preceded by characters other than a space or a tab in a line or
             if there is no "$end" at the end of the file.
     """
-    if '$' not in string:
+    if "$" not in string:
         raise ValueError('No dollar ("$") sign in the string.')
     if cleanup_types is None:
-        cleanup_types = ["BLANK_LINES", "LEADING_SPACES_DOLLAR",
-                         "LEADING_SPACES_HASH", "BEFORE_FIRST_DOLLAR"]
+        cleanup_types = [
+            "BLANK_LINES",
+            "LEADING_SPACES_DOLLAR",
+            "LEADING_SPACES_HASH",
+            "BEFORE_FIRST_DOLLAR",
+        ]
     for cleanup_type in cleanup_types:
         # Removing lines before the first dollar sign (except if this dollar
         # sign is in a hash comment)
-        if cleanup_type == 'BEFORE_FIRST_DOLLAR':
+        if cleanup_type == "BEFORE_FIRST_DOLLAR":
             newlines = []
             after_first_dollar = False
-            for line in string.split('\n'):
-                if after_first_dollar or line.strip().startswith('#'):
+            for line in string.split("\n"):
+                if after_first_dollar or line.strip().startswith("#"):
                     newlines.append(line)
-                elif line.strip().startswith('$'):
+                elif line.strip().startswith("$"):
                     after_first_dollar = True
                     newlines.append(line.lstrip())
-            string = '\n'.join(newlines)
+            string = "\n".join(newlines)
         # Removing all blank lines
-        elif cleanup_type == 'BLANK_LINES':
-            string = re.sub(r'(\n[ \t]*){2,}', '\n', string,
-                            flags=re.MULTILINE)
+        elif cleanup_type == "BLANK_LINES":
+            string = re.sub(r"(\n[ \t]*){2,}", "\n", string, flags=re.MULTILINE)
         # Removing all spaces and tabs before dollar signs
-        elif cleanup_type == 'LEADING_SPACES_DOLLAR':
-            string = re.sub(r'^[ \t]*\$', '$', string,
-                            flags=re.MULTILINE)
+        elif cleanup_type == "LEADING_SPACES_DOLLAR":
+            string = re.sub(r"^[ \t]*\$", "$", string, flags=re.MULTILINE)
         # Removing all spaces before hash signs
-        elif cleanup_type == 'LEADING_SPACES_HASH':
-            string = re.sub(r'^[ \t]*#', '#', string,
-                            flags=re.MULTILINE)
+        elif cleanup_type == "LEADING_SPACES_HASH":
+            string = re.sub(r"^[ \t]*#", "#", string, flags=re.MULTILINE)
         else:
-            raise ValueError('Cleanup of type "{}" '
-                             'is not a valid type.'.format(cleanup_type))
+            raise ValueError(
+                'Cleanup of type "{}" ' "is not a valid type.".format(cleanup_type)
+            )
 
-    for match in re.findall(pattern=r'^[ \t\S]+\$',
-                            string=string,
-                            flags=re.MULTILINE):
-        if not match.strip().startswith('#'):
-            raise ValueError('Some character(s) are preceding a '
-                             'dollar ("$") sign.')
+    for match in re.findall(pattern=r"^[ \t\S]+\$", string=string, flags=re.MULTILINE):
+        if not match.strip().startswith("#"):
+            raise ValueError("Some character(s) are preceding a " 'dollar ("$") sign.')
 
-    if '$end' not in string:
+    if "$end" not in string:
         raise ValueError('No "$end" in the string.')
     return string
 
 
 def remove_comments(string, comment_types=None):
-    """Returns a data group string with comment lines removed.
+    """Return a data group string with comment lines removed.
 
     Comments or additional information in TurboMole is typically specified in
     three different ways : a line starting with a hash ("#") symbol, a data
@@ -149,44 +147,41 @@ def remove_comments(string, comment_types=None):
         comment_types = ["HASH_START", "DUMMY", "AFTER_END", "HASH_INLINE"]
     for comment_type in comment_types:
         # Removing lines starting with a hash symbol
-        if comment_type == 'HASH_START':
-            string = re.sub(r'^#.*\n?', '', string, flags=re.MULTILINE)
+        if comment_type == "HASH_START":
+            string = re.sub(r"^#.*\n?", "", string, flags=re.MULTILINE)
         # Removing portions of the file corresponding to a $dummy data group
-        elif comment_type == 'DUMMY':
+        elif comment_type == "DUMMY":
             old = None
             # Loop is needed because replaced characters are not used in
             # consecutive regex searches
             while old != string:
                 old = string
-                string = re.sub(r'^\$dummy[^$]*\$', '$', string,
-                                flags=re.MULTILINE)
+                string = re.sub(r"^\$dummy[^$]*\$", "$", string, flags=re.MULTILINE)
             # Dummy data group at the end of the file
-            string = re.sub(r'^\$dummy[\s\S]*\Z', '', string,
-                            flags=re.MULTILINE)
+            string = re.sub(r"^\$dummy[\s\S]*\Z", "", string, flags=re.MULTILINE)
         # Removing lines after $end
-        elif comment_type == 'AFTER_END':
-            string = re.sub(r'^\$end[\s\S]*\Z', '$end\n', string,
-                            flags=re.MULTILINE)
+        elif comment_type == "AFTER_END":
+            string = re.sub(r"^\$end[\s\S]*\Z", "$end\n", string, flags=re.MULTILINE)
         # Removing inline comments i.e. #-starting comments in the middle of
         # a line (e.g. : "$symmetry c1 # Symmetry of the system")
         # Note that lines starting with a hash symbol will also be replaced
         # by a blank line
-        elif comment_type == 'HASH_INLINE':
+        elif comment_type == "HASH_INLINE":
             # Only matches if there is something other than white spaces
             # before the hash ("#") symbol. Only the first capturing group
             # is reinserted with the "\1", while the lookahead ("(?=$)") is
             # checking for the end of the line but leaving it as it is, be it
             # a newline or an end of file.
-            string = re.sub(r'(^\s*\S.*?)(#.*)(?=$)', r'\1', string, flags=re.MULTILINE)
+            string = re.sub(r"(^\s*\S.*?)(#.*)(?=$)", r"\1", string, flags=re.MULTILINE)
         else:
-            raise ValueError('Comment of type "{}" '
-                             'is not a valid type.'.format(comment_type))
+            raise ValueError(
+                'Comment of type "{}" ' "is not a valid type.".format(comment_type)
+            )
     return string
 
 
-def split_string_to_dg_list(string, cleanup_types=None,
-                            remove_comment_types=None):
-    r"""Splits a string into a list of data groups.
+def split_string_to_dg_list(string, cleanup_types=None, remove_comment_types=None):
+    r"""Split a string into a list of data groups.
 
     Args:
         string (str): A string that should be in the "data group" format of
@@ -224,14 +219,14 @@ def split_string_to_dg_list(string, cleanup_types=None,
         ...                         " global     off\n"
         ...                         " basis      off\n")
         ['$title\n', '$optimize\n internal   on\n redundant  on\n cartesian  off\n global     off\n basis      off\n']
-    """
+    """  # noqa: E501
     string = cleanup_string(string=string, cleanup_types=cleanup_types)
     string = remove_comments(string=string, comment_types=remove_comment_types)
-    return ['$' + dg for dg in string.split('$')[1:]]
+    return ["$" + dg for dg in string.split("$")[1:]]
 
 
 def remove_dg_from_list(dg_to_remove, dg_list, strict=True):
-    """Returns new list with a data group removed from the initial list.
+    """Return new list with a data group removed from the initial list.
 
     This function will remove dg_to_remove from a list of data groups. If the
     data group is duplicated, all occurrences are removed. The standard usage
@@ -257,9 +252,9 @@ def remove_dg_from_list(dg_to_remove, dg_list, strict=True):
         dg_to_remove = dg_to_remove[1:]
     new_dg_list = []
     if strict:
-        pattern = r'^\$' + dg_to_remove + r'\s'
+        pattern = r"^\$" + dg_to_remove + r"\s"
     else:
-        pattern = r'^\$' + dg_to_remove
+        pattern = r"^\$" + dg_to_remove
     for dg in dg_list:
         if not re.match(pattern=pattern, string=dg):
             new_dg_list.append(dg)
@@ -268,7 +263,8 @@ def remove_dg_from_list(dg_to_remove, dg_list, strict=True):
 
 def compare_datagroup_string(dg1, dg2, tol=None):
     """
-    Compares to datagroup strings as split from the DataGroups object.
+    Compare two datagroup strings as split from the DataGroups object.
+
     Return True if the two match.
     The two strings should have the same number of lines. Each line should have the
     same number of chunks. Chunks will be separated using spaces and "=". Each chunk
@@ -285,7 +281,6 @@ def compare_datagroup_string(dg1, dg2, tol=None):
     Returns:
         bool: True if the string match.
     """
-
     lines1 = dg1.splitlines()
     lines2 = dg2.splitlines()
 
@@ -321,7 +316,7 @@ class DataGroups(MSONable):
     """
 
     def __init__(self, string=None, dg_list=None):
-        """Initializes a `DataGroups` class.
+        """Initialize a `DataGroups` class.
 
         The DataGroups object defines a set of key-value-like pairs. A data
         group is a key starting with a dollar ("$") sign. The value
@@ -342,18 +337,18 @@ class DataGroups(MSONable):
             if string is None:
                 raise ValueError('Both "string" and "dg_list" are None.')
             self.initial_string = string
-            self.dg_list = split_string_to_dg_list(string=string,
-                                                   cleanup_types=None,
-                                                   remove_comment_types=None)
+            self.dg_list = split_string_to_dg_list(
+                string=string, cleanup_types=None, remove_comment_types=None
+            )
         else:
             self.dg_list = dg_list
             if string is None:
-                self.initial_string = ''.join(dg_list)
+                self.initial_string = "".join(dg_list)
             else:
                 self.initial_string = string
 
     def kill_data_group(self, data_group, strict=True):
-        """Removes `data_group` from this `DataGroups` object.
+        """Remove `data_group` from this `DataGroups` object.
 
         Args:
             data_group (str): Data group to be removed.
@@ -361,14 +356,14 @@ class DataGroups(MSONable):
                 If False, any Data group starting with `data_group` will be
                 removed.
         """
-        self.dg_list = remove_dg_from_list(dg_to_remove=data_group,
-                                           dg_list=self.dg_list,
-                                           strict=strict)
+        self.dg_list = remove_dg_from_list(
+            dg_to_remove=data_group, dg_list=self.dg_list, strict=strict
+        )
 
     kdg = kill_data_group
 
     def add_data_group(self, data_group, data_block):
-        """Adds `data_group`->`data_block` to this `DataGroups` object.
+        """Add `data_group`->`data_block` to this `DataGroups` object.
 
         Args:
             data_group (str): Data group (key) to be added. The dollar ("$")
@@ -378,31 +373,39 @@ class DataGroups(MSONable):
         Raises:
             RuntimeError: if data_group already exists.
         """
-        if data_group[0] != '$':
-            data_group = '$' + data_group
-        if self.show_data_group(data_group=data_group,
-                                strict=True) is not None:
-            raise RuntimeError('Data group "{}" already exists in this '
-                               'DataGroups object.'.format(data_group))
-        if not re.fullmatch(pattern=r'^\$[a-zA-Z][ \-\w\(\)]*', string=data_group):
-            raise ValueError('Data group should start with a letter and be '
-                             'followed by alphanumeric characters, a space, '
-                             '"-", "_", "(" or ")".')
-        if not data_block.endswith('\n'):
-            data_block = data_block + '\n'
-        if data_block.startswith((' ', '\t', '\n')):
-            self.dg_list.insert(-1, '{}{}'.format(data_group, data_block))
+        if data_group[0] != "$":
+            data_group = "$" + data_group
+        if self.show_data_group(data_group=data_group, strict=True) is not None:
+            raise RuntimeError(
+                'Data group "{}" already exists in this '
+                "DataGroups object.".format(data_group)
+            )
+        if not re.fullmatch(pattern=r"^\$[a-zA-Z][ \-\w\(\)]*", string=data_group):
+            raise ValueError(
+                "Data group should start with a letter and be "
+                "followed by alphanumeric characters, a space, "
+                '"-", "_", "(" or ")".'
+            )
+        if not data_block.endswith("\n"):
+            data_block = data_block + "\n"
+        if data_block.startswith((" ", "\t", "\n")):
+            self.dg_list.insert(-1, "{}{}".format(data_group, data_block))
         else:
-            self.dg_list.insert(-1, '{} {}'.format(data_group, data_block))
+            self.dg_list.insert(-1, "{} {}".format(data_group, data_block))
 
     adg = add_data_group
 
-    def show_data_group(self, data_group, strict=True, default=None,
-                        show_from_subfile=True,
-                        raise_if_multiple_subfiles=False,
-                        raise_if_missing_subfile=False,
-                        raise_if_regular_and_subfile=False):
-        """Shows `data_group` from this `DataGroups` object.
+    def show_data_group(
+        self,
+        data_group,
+        strict=True,
+        default=None,
+        show_from_subfile=True,
+        raise_if_multiple_subfiles=False,
+        raise_if_missing_subfile=False,
+        raise_if_regular_and_subfile=False,
+    ):
+        """Show `data_group` from this `DataGroups` object.
 
         Args:
 
@@ -439,13 +442,12 @@ class DataGroups(MSONable):
                 regular data block options coexist with a reference to a subfile
                  (and raise_if_regular_and_subfile is True).
         """
-
         if data_group[0] == "$":
             data_group = data_group[1:]
         if strict:
-            pattern = r'^\$' + data_group + r'[=\s]'
+            pattern = r"^\$" + data_group + r"[=\s]"
         else:
-            pattern = r'^\$' + data_group
+            pattern = r"^\$" + data_group
 
         matches = []
         for dg in self.dg_list:
@@ -453,27 +455,31 @@ class DataGroups(MSONable):
                 matches.append(dg)
         if len(matches) == 0:
             return default
-        dollar_data_group = '$' + data_group
+        dollar_data_group = "$" + data_group
         if len(matches) > 1:
-            raise RuntimeError('Found multiple occurrences of data group '
-                               '"{}".'.format(dollar_data_group))
+            raise RuntimeError(
+                "Found multiple occurrences of data group "
+                '"{}".'.format(dollar_data_group)
+            )
         if strict:
-            data_block = matches[0].replace(dollar_data_group, '')
+            data_block = matches[0].replace(dollar_data_group, "")
         else:
-            match = re.sub(r'^\$' + data_group + r'[-\w]*', '', matches[0])
-            data_block = re.sub(r'^ ', '', match)
+            match = re.sub(r"^\$" + data_group + r"[-\w]*", "", matches[0])
+            data_block = re.sub(r"^ ", "", match)
 
         if not show_from_subfile:
             return data_block
 
-        subfiles_count = data_block.count('file=')
+        subfiles_count = data_block.count("file=")
         if subfiles_count == 0:
             return data_block
         elif subfiles_count == 1:
-            filename = self._get_subfile_fname(data_block=data_block,
-                                               raise_if_regular_and_subfile=raise_if_regular_and_subfile)
+            filename = self._get_subfile_fname(
+                data_block=data_block,
+                raise_if_regular_and_subfile=raise_if_regular_and_subfile,
+            )
             if os.path.exists(filename):
-                with open(filename, 'r') as f:
+                with open(filename, "r") as f:
                     subfile_string = f.read()
 
                 if subfile_string.strip():
@@ -481,8 +487,10 @@ class DataGroups(MSONable):
                     return subfile.show_data_group(data_group=data_group)
 
             if raise_if_missing_subfile:
-                raise RuntimeError('File "{}" for data group "{}" is '
-                                   'missing or empty.'.format(filename, data_group))
+                raise RuntimeError(
+                    'File "{}" for data group "{}" is '
+                    "missing or empty.".format(filename, data_group)
+                )
             return data_block
         elif raise_if_multiple_subfiles:
             raise RuntimeError('Multiple "file=FILENAME" directives.')
@@ -492,9 +500,9 @@ class DataGroups(MSONable):
     sdg = show_data_group
 
     def change_data_group(self, data_group, data_block):
-        """
-        Changes the value of the `data_group` to the new `data_block` in this
-        `DataGroups` object. If the key is not present will be added.
+        """Change the value of the `data_group` to the new `data_block`.
+
+        If the key is not present will be added.
 
         It will first apply the kill_data_group and then add_data_group. Note
         that in the current implementation, the data group will be moved to
@@ -511,7 +519,6 @@ class DataGroups(MSONable):
                 If None it will simply kill_data_group for the specified
                 data_group value.
         """
-
         self.kill_data_group(data_group=data_group, strict=True)
         if data_block is not None:
             self.add_data_group(data_group=data_group, data_block=data_block)
@@ -519,7 +526,8 @@ class DataGroups(MSONable):
     cdg = change_data_group
 
     def modify_data_group_options(self, data_group, options):
-        """
+        """Modify a data group option.
+
         Given a data group that allows several options on separate line
         (e.g. $dft), updates the values of the options according to the
         dictionary provided.
@@ -548,7 +556,6 @@ class DataGroups(MSONable):
             options (dict): The options that should be added or updated. If the
                 value of one key is None the option will be removed if present.
         """
-
         dg = self.show_data_group(data_group, strict=True)
 
         # start from a line  with a space if dg is not present (should not be empty)
@@ -558,19 +565,19 @@ class DataGroups(MSONable):
         # copy the dict as it will modified
         options = dict(options)
         new_lines = []
-        for l in dg.splitlines():
+        for line in dg.splitlines():
             # check if one of the lines matches the options. If yes replace
-            # the line and remove it from the optiond dict, otherwise keep
-            # the oriiginal line.
+            # the line and remove it from the options dict, otherwise keep
+            # the original line.
             for opt in list(options.keys()):
-                if opt in l:
+                if opt in line:
                     opt_kv = options.pop(opt)
                     # if None skip the line
                     if opt_kv is not None:
                         new_lines.append("   " + opt_kv)
                     break
             else:
-                new_lines.append(l)
+                new_lines.append(line)
 
         # add all the options that were not present in the original set
         # except for None. Sorted so that the results are deterministic
@@ -584,7 +591,8 @@ class DataGroups(MSONable):
     mdgo = modify_data_group_options
 
     def show_data_group_option(self, data_group, option, default=None):
-        """
+        """Show a data group option.
+
         Given a data group that allows several options on separate line
         (e.g. $dft), returns the value of the option provided.
 
@@ -603,16 +611,19 @@ class DataGroups(MSONable):
         Returns:
             str: The value of the option.
         """
-
-        dg = self.show_data_group(data_group, strict=True, show_from_subfile=True,
-                                  raise_if_missing_subfile=False)
+        dg = self.show_data_group(
+            data_group,
+            strict=True,
+            show_from_subfile=True,
+            raise_if_missing_subfile=False,
+        )
 
         if dg is None:
             return default
 
         compiled_re = re.compile(r"\s*{}(.*)$".format(option), re.DOTALL)
-        for l in dg.splitlines():
-            match = compiled_re.match(l)
+        for line in dg.splitlines():
+            match = compiled_re.match(line)
             if match:
                 return match.group(1)
 
@@ -622,58 +633,62 @@ class DataGroups(MSONable):
 
     @property
     def number_of_data_groups(self):
+        """Get the number of datagroups in this DataGroups object."""
         return len(self.dg_list) - 1
 
     ndg = number_of_data_groups
 
     @classmethod
     def empty(cls):
-        """Creates an empty DataGroups object.
+        """Create an empty DataGroups object.
 
         An empty DataGroups object only contains the "$end" data group.
         """
-        return cls(dg_list=['$end\n'])
+        return cls(dg_list=["$end\n"])
 
     def as_dict(self):
-        """Returns a dictionary representing the DataGroups object."""
-        return {"@module": self.__class__.__module__,
-                "@class": self.__class__.__name__,
-                "string": self.initial_string,
-                "dg_list": self.dg_list}
+        """Return a dictionary representing the DataGroups object."""
+        return {
+            "@module": self.__class__.__module__,
+            "@class": self.__class__.__name__,
+            "string": self.initial_string,
+            "dg_list": self.dg_list,
+        }
 
     @classmethod
     def from_dict(cls, d):
-        """Creates DataGroups object from a dictionary."""
-        return cls(string=d['string'], dg_list=d['dg_list'])
+        """Create DataGroups object from a dictionary."""
+        return cls(string=d["string"], dg_list=d["dg_list"])
 
     def __str__(self):
-        """Returns string representation of this DataGroups object.
+        """Return a string representation of this DataGroups object.
 
         The string representation of the DataGroups object is supposed to be
         written to a file and used as an input to TurboMole executables.
         """
-        return ''.join(self.dg_list)
+        return "".join(self.dg_list)
 
     def to_file(self, filename):
-        """Writes this DataGroups object to a file.
+        """Write this DataGroups object to a file.
+
         If the file exists it will be overwritten.
 
         Args:
             filename (str): Name of the file to which this DataGroups object
                 should be written.
         """
-        with open(filename, 'w') as f:
+        with open(filename, "w") as f:
             f.write(self.__str__())
 
     @classmethod
     def from_file(cls, filename):
-        """Creates DataGroups object reading from a given file.
+        """Create DataGroups object reading from a given file.
 
         Args:
             filename (str): Name of the file from which this DataGroups object
                 should be read.
         """
-        with open(filename, 'r') as f:
+        with open(filename, "r") as f:
             string = f.read()
         return cls(string=string)
 
@@ -695,18 +710,20 @@ class DataGroups(MSONable):
             RuntimeError: if raise_if_regular_and_subfile is True and file=FILENAME
                 is not the only content of the string.
         """
-        pattern = r'file=([^\s]+)'
+        pattern = r"file=([^\s]+)"
         match = re.search(pattern=pattern, string=data_block)
 
         if not match:
             return None
 
-        data_block_test = data_block.replace(match.group(0), '')
+        data_block_test = data_block.replace(match.group(0), "")
         data_block_test = data_block_test.strip()
-        if data_block_test != '' and raise_if_regular_and_subfile:
-            raise RuntimeError('Both a reference to a file '
-                               '("file=FILENAME") and regular data '
-                               'blocks are in the data group.')
+        if data_block_test != "" and raise_if_regular_and_subfile:
+            raise RuntimeError(
+                "Both a reference to a file "
+                '("file=FILENAME") and regular data '
+                "blocks are in the data group."
+            )
         return match.group(1)
 
     def show_subfile_fname(self, data_group, raise_if_regular_and_subfile=False):
@@ -726,53 +743,62 @@ class DataGroups(MSONable):
             RuntimeError: if raise_if_regular_and_subfile is True and file=FILENAME
                 is not the only content of the string.
         """
-        return self._get_subfile_fname(self.sdg(data_group, show_from_subfile=False),
-                                       raise_if_regular_and_subfile=raise_if_regular_and_subfile)
+        return self._get_subfile_fname(
+            self.sdg(data_group, show_from_subfile=False),
+            raise_if_regular_and_subfile=raise_if_regular_and_subfile,
+        )
 
     def compare(self, datagroups, tol=None, ignored_dg=None, return_all_diffs=False):
         """
-        Compares the current object with another DataGroups. Aside from the datagroups
-        that should be ignored, (define in the ignored_dg argument), the two should contain
-        the same amount of elements in dg_list and each one from the current object
-        should have a matching elements in the one that is passed as argument.
-        To match two strings should have the same number of lines. Each line should have the
-        same number of chunks. Each chunk should match exactly as a string, except if
-        they are numbers. In that, if a tol is specified they will be converted to float
-        and their difference should be lower than the tolerance.
+        Compare the current object with another DataGroups.
+
+        Aside from the datagroups that should be ignored, (define in the
+        ignored_dg argument), the two should contain the same amount of elements in
+        dg_list and each one from the current object should have a matching elements
+        in the one that is passed as argument.
+        To match two strings should have the same number of lines. Each line should
+        have the same number of chunks. Each chunk should match exactly as a string,
+        except if they are numbers. In that, if a tol is specified they will be
+        converted to float and their difference should be lower than the tolerance.
 
         If the two objects match None will be returned, otherwise a message describing
         the property that caused the match to fail.
 
-        Note that, given the variety of notations supported by Turbomole, this function is to
-        be intended more for testing purposes rather than as a complete tool to guarantee the
-        equivalence of two control file.
+        Note that, given the variety of notations supported by Turbomole, this
+        function is to be intended more for testing purposes rather than as a complete
+        tool to guarantee the equivalence of two control file.
 
         Args:
-            datagroups (DataGroups): a Datagroups that should match with the current instance.
+            datagroups (DataGroups): a Datagroups that should match with the
+                current instance.
             tol (float): the tolerance allowed when comparing numbers. If None
                 even the number should match as strings.
-            ignored_dg (list): a list of datagroups that should be ignored for the comparison.
-                It is expected to be the name of the datagroup, thus starting with a "$".
-                If the "$" symbol is not present will be added before trying to match the
-                datagroup to skip.
-            return_all_diffs (bool): If True, a list of all differences is returned. If False
-                (default), a string describing the first source of difference found is returned.
+            ignored_dg (list): a list of datagroups that should be ignored for
+                the comparison. It is expected to be the name of the datagroup,
+                thus starting with a "$".
+                If the "$" symbol is not present will be added before trying to
+                match the datagroup to skip.
+            return_all_diffs (bool): If True, a list of all differences is returned.
+                If False (default), a string describing the first source of
+                difference found is returned.
 
         Returns:
-            None if the results match or a string describing a source of difference otherwise
-                (if return_all_diffs is False) or a list of all differences (if return_all_diffs
-                is True).
+            None if the results match or a string describing a source of difference
+                otherwise (if return_all_diffs is False) or a list of all differences
+                (if return_all_diffs is True).
         """
-
         dg_other_list = list(datagroups.dg_list)
         diffs = []
 
         if ignored_dg:
-            # add the initial $ to each datagroup if not already present
-            ignored_dg = ["$" + dg if not dg.startswith("$") else dg for dg in ignored_dg]
+            # add the initial $ to each datagroup if not already present.
+            ignored_dg = [
+                "$" + dg if not dg.startswith("$") else dg for dg in ignored_dg
+            ]
 
         for dg1 in self.dg_list:
-            # skip the check if dg1 matches the list of datagroups that should be ignored
+            # skip the check if dg1 matches the list of datagroups that should
+            # be ignored.
             if ignored_dg and any(dg1.startswith(dg) for dg in ignored_dg):
                 continue
             for i, dg2 in enumerate(dg_other_list):
@@ -780,17 +806,22 @@ class DataGroups(MSONable):
                     dg_other_list.pop(i)
                     break
             else:
-                msg = "Datagroup does not match to any of the references: {}".format(dg1)
+                msg = "Datagroup does not match to any of the references: {}".format(
+                    dg1
+                )
                 if return_all_diffs:
                     diffs.append(msg)
                 else:
                     return msg
 
-        # check that all the remaining datagroups in the second control belong to the ignore list
+        # check that all the remaining datagroups in the second control belong
+        # to the ignore list.
         for dg2 in dg_other_list:
             if not ignored_dg or not any(dg2.startswith(dg) for dg in ignored_dg):
-                msg = "Datagroup in the reference does not match to any of the current " \
-                      "control: {}".format(dg2)
+                msg = (
+                    "Datagroup in the reference does not match to any of the current "
+                    "control: {}".format(dg2)
+                )
                 if return_all_diffs:
                     diffs.append(msg)
                 else:
