@@ -2,7 +2,7 @@
 # The turbomoleio package, a python interface to Turbomole
 # for preparing inputs, parsing outputs and other related tools.
 #
-# Copyright (C) 2018-2021 BASF SE, Matgenix SRL.
+# Copyright (C) 2018-2022 BASF SE, Matgenix SRL.
 #
 # This file is part of turbomoleio.
 #
@@ -22,20 +22,25 @@
 
 import os
 import re
-import pexpect
 import signal
 import subprocess
-import pytest
-from pexpect.popen_spawn import PopenSpawn
 from unittest import mock
-from monty.os import makedirs_p
-from monty.collections import dict2namedtuple
 
-from turbomoleio.testfiles.utils import temp_dir, touch_file
-from turbomoleio.input.define import DefineError, DefineParameterError, DefineExpectError, UnsupportedDefineStateError
-from turbomoleio.input.define import DefineIredError
-from turbomoleio.input.define import DefineRunner
+import pexpect
+import pytest
+from monty.collections import dict2namedtuple
+from monty.os import makedirs_p
+
 from turbomoleio.core.control import Control
+from turbomoleio.input.define import (
+    DefineError,
+    DefineExpectError,
+    DefineIredError,
+    DefineParameterError,
+    DefineRunner,
+    UnsupportedDefineStateError,
+)
+from turbomoleio.testfiles.utils import temp_dir, touch_file
 
 
 class TestExceptions(object):
@@ -44,11 +49,11 @@ class TestExceptions(object):
     """
 
     def test_create(self):
-        de = DefineError("test error")
-        dpe = DefineParameterError("test error")
-        die = DefineIredError("test error")
-        dee = DefineExpectError("test error", pattern=["pattern1", "pattern2"])
-        udse = UnsupportedDefineStateError("test error")
+        DefineError("test error")
+        DefineParameterError("test error")
+        DefineIredError("test error")
+        DefineExpectError("test error", pattern=["pattern1", "pattern2"])
+        UnsupportedDefineStateError("test error")
 
 
 @pytest.fixture(scope="function", params=[True, False], ids=["use_popen", "use_pty"])
@@ -68,8 +73,15 @@ def dr_data(request):
     expect_mock = dr.define.expect
     sendline_mock = dr.define.sendline
 
-    data = dict2namedtuple(dict(use_popen=use_popen, dr=dr, expect_mock=expect_mock,
-                                sendline_mock=sendline_mock, spawn_class=spawn_class))
+    data = dict2namedtuple(
+        dict(
+            use_popen=use_popen,
+            dr=dr,
+            expect_mock=expect_mock,
+            sendline_mock=sendline_mock,
+            spawn_class=spawn_class,
+        )
+    )
 
     return data
 
@@ -91,7 +103,9 @@ str_state_selection_menu = b"""STATE SELECTION MENU
  ENTER ? FOR HELP, * OR Q TO QUIT, & TO GO BACK
 """
 
-match_ex_state_selection = re.search(b"----.*SELECT IRREP AND NUMBER OF STATES", str_state_selection_menu, re.DOTALL)
+match_ex_state_selection = re.search(
+    b"----.*SELECT IRREP AND NUMBER OF STATES", str_state_selection_menu, re.DOTALL
+)
 
 str_response_menu_u_off = b""" MAIN MENU FOR RESPONSE CALCULATIONS
 
@@ -105,15 +119,29 @@ str_response_menu_u_off = b""" MAIN MENU FOR RESPONSE CALCULATIONS
  ENTER <OPTION> TO SWITCH ON/OFF OPTION, * OR q TO QUIT
 """
 
-match_ex_response_u_off = re.search(b"----.*ENTER <OPTION> TO SWITCH ON/OFF OPTION", str_response_menu_u_off, re.DOTALL)
+match_ex_response_u_off = re.search(
+    b"----.*ENTER <OPTION> TO SWITCH ON/OFF OPTION", str_response_menu_u_off, re.DOTALL
+)
 
-str_response_menu_urpa_on = bytes(str_response_menu_u_off).replace(b"urpa   | off", b"urpa   | on ")
+str_response_menu_urpa_on = bytes(str_response_menu_u_off).replace(
+    b"urpa   | off", b"urpa   | on "
+)
 
-match_ex_response_urpa_on = re.search(b"----.*ENTER <OPTION> TO SWITCH ON/OFF OPTION", str_response_menu_urpa_on, re.DOTALL)
+match_ex_response_urpa_on = re.search(
+    b"----.*ENTER <OPTION> TO SWITCH ON/OFF OPTION",
+    str_response_menu_urpa_on,
+    re.DOTALL,
+)
 
-str_response_menu_ucis_on = bytes(str_response_menu_u_off).replace(b"ucis   | off", b"ucis   | on ")
+str_response_menu_ucis_on = bytes(str_response_menu_u_off).replace(
+    b"ucis   | off", b"ucis   | on "
+)
 
-match_ex_response_ucis_on = re.search(b"----.*ENTER <OPTION> TO SWITCH ON/OFF OPTION", str_response_menu_ucis_on, re.DOTALL)
+match_ex_response_ucis_on = re.search(
+    b"----.*ENTER <OPTION> TO SWITCH ON/OFF OPTION",
+    str_response_menu_ucis_on,
+    re.DOTALL,
+)
 
 str_response_menu_st_off = b""" MAIN MENU FOR RESPONSE CALCULATIONS
 
@@ -132,15 +160,29 @@ str_response_menu_st_off = b""" MAIN MENU FOR RESPONSE CALCULATIONS
  ENTER <OPTION> TO SWITCH ON/OFF OPTION, * OR q TO QUIT
 """
 
-match_ex_response_st_off = re.search(b"----.*ENTER <OPTION> TO SWITCH ON/OFF OPTION", str_response_menu_st_off, re.DOTALL)
+match_ex_response_st_off = re.search(
+    b"----.*ENTER <OPTION> TO SWITCH ON/OFF OPTION", str_response_menu_st_off, re.DOTALL
+)
 
-str_response_menu_rpas_on = bytes(str_response_menu_st_off).replace(b"rpas   | off", b"rpas   | on ")
+str_response_menu_rpas_on = bytes(str_response_menu_st_off).replace(
+    b"rpas   | off", b"rpas   | on "
+)
 
-match_ex_response_rpas_on = re.search(b"----.*ENTER <OPTION> TO SWITCH ON/OFF OPTION", str_response_menu_rpas_on, re.DOTALL)
+match_ex_response_rpas_on = re.search(
+    b"----.*ENTER <OPTION> TO SWITCH ON/OFF OPTION",
+    str_response_menu_rpas_on,
+    re.DOTALL,
+)
 
-str_response_menu_polly_on = bytes(str_response_menu_st_off).replace(b"polly  | off", b"polly  | on ")
+str_response_menu_polly_on = bytes(str_response_menu_st_off).replace(
+    b"polly  | off", b"polly  | on "
+)
 
-match_ex_response_polly_on = re.search(b"----.*ENTER <OPTION> TO SWITCH ON/OFF OPTION", str_response_menu_polly_on, re.DOTALL)
+match_ex_response_polly_on = re.search(
+    b"----.*ENTER <OPTION> TO SWITCH ON/OFF OPTION",
+    str_response_menu_polly_on,
+    re.DOTALL,
+)
 
 str_response_menu_wrong = b""" MAIN MENU FOR RESPONSE CALCULATIONS
 
@@ -152,7 +194,9 @@ str_response_menu_wrong = b""" MAIN MENU FOR RESPONSE CALCULATIONS
  ENTER <OPTION> TO SWITCH ON/OFF OPTION, * OR q TO QUIT
 """
 
-match_ex_response_wrong = re.search(b"----.*ENTER <OPTION> TO SWITCH ON/OFF OPTION", str_response_menu_wrong, re.DOTALL)
+match_ex_response_wrong = re.search(
+    b"----.*ENTER <OPTION> TO SWITCH ON/OFF OPTION", str_response_menu_wrong, re.DOTALL
+)
 
 
 class TestDefineRunner(object):
@@ -209,7 +253,10 @@ class TestDefineRunner(object):
     def test_close(self, dr_data):
         dr = dr_data.dr
         dr.define = mock.Mock(dr_data.spawn_class)
-        with mock.patch("turbomoleio.input.define.DefineRunner._is_alive", new_callable=mock.PropertyMock) as is_alive:
+        with mock.patch(
+            "turbomoleio.input.define.DefineRunner._is_alive",
+            new_callable=mock.PropertyMock,
+        ) as is_alive:
             is_alive.return_value = True
             dr._close()
 
@@ -234,14 +281,20 @@ class TestDefineRunner(object):
 
     def test_expect_raise_timeout(self, dr_data):
         dr_data.expect_mock.side_effect = pexpect.exceptions.TIMEOUT("timeout")
-        with mock.patch("turbomoleio.input.define.DefineRunner._is_alive", new_callable=mock.PropertyMock) as is_alive:
+        with mock.patch(
+            "turbomoleio.input.define.DefineRunner._is_alive",
+            new_callable=mock.PropertyMock,
+        ) as is_alive:
             is_alive.return_value = True
             with pytest.raises(DefineExpectError):
                 dr_data.dr._expect(["pattern"], timeout=2, action="test action")
 
     def test_expect_raise_eof(self, dr_data):
         dr_data.expect_mock.side_effect = pexpect.exceptions.EOF("eof")
-        with mock.patch("turbomoleio.input.define.DefineRunner._is_alive", new_callable=mock.PropertyMock) as is_alive:
+        with mock.patch(
+            "turbomoleio.input.define.DefineRunner._is_alive",
+            new_callable=mock.PropertyMock,
+        ) as is_alive:
             is_alive.return_value = False
             with pytest.raises(DefineExpectError):
                 dr_data.dr._expect(["pattern"], timeout=2, action="test action")
@@ -258,14 +311,19 @@ class TestDefineRunner(object):
         assert "test action" in message
         dr_data.sendline_mock.assert_called_once_with("command")
 
-    @pytest.mark.parametrize('dir_name', ['mos_nh3'])
+    @pytest.mark.parametrize("dir_name", ["mos_nh3"])
     def test_run_full_1(self, dr_data, mo_dirpath, delete_tmp_dir):
         with temp_dir(delete_tmp_dir) as tmp_dir:
             dr_data.dr.workdir = tmp_dir
             other_control = os.path.join(tmp_dir, "control2")
             touch_file(other_control)
-            dr_data.dr.parameters = {"method": "dft", "ex_method": "rpa", "usemo": other_control,
-                                     "copymo": mo_dirpath, "use_cosmo": True}
+            dr_data.dr.parameters = {
+                "method": "dft",
+                "ex_method": "rpa",
+                "usemo": other_control,
+                "copymo": mo_dirpath,
+                "use_cosmo": True,
+            }
             dr_data.expect_mock.side_effect = iter(int, 1)
             # mock these functions to not having failures due to case == 0
             dr_data.dr._copy_mo_files = mock.MagicMock()
@@ -273,10 +331,14 @@ class TestDefineRunner(object):
             dr_data.dr._add_cosmo = mock.MagicMock()
             dr_data.dr._spawn = mock.MagicMock()
             dr_data.dr._spawn.return_value = dr_data.dr.define
-            se = [match_ex_response_st_off, match_ex_response_rpas_on, match_ex_state_selection]
+            se = [
+                match_ex_response_st_off,
+                match_ex_response_rpas_on,
+                match_ex_state_selection,
+            ]
             type(dr_data.dr.define).match = mock.PropertyMock(side_effect=se)
 
-            #create an empty control file for the postprocess
+            # create an empty control file for the postprocess
             Control.empty().to_file()
 
             assert dr_data.dr.run_full()
@@ -290,7 +352,11 @@ class TestDefineRunner(object):
             dr_data.dr._copy_mo_files = mock.MagicMock()
             dr_data.dr._spawn = mock.MagicMock()
             dr_data.dr._spawn.return_value = dr_data.dr.define
-            se = [match_ex_response_st_off, match_ex_response_rpas_on, match_ex_state_selection]
+            se = [
+                match_ex_response_st_off,
+                match_ex_response_rpas_on,
+                match_ex_state_selection,
+            ]
             type(dr_data.dr.define).match = mock.PropertyMock(side_effect=se)
             if dr_data.use_popen:
                 # set poll to None so that kill is called and cover all cases
@@ -306,7 +372,7 @@ class TestDefineRunner(object):
                 dr_data.dr.define.close.assert_called_once_with(force=True)
             self.assert_sendline_calls(dr_data.sendline_mock, dr_data.dr.sent_commands)
 
-    @pytest.mark.parametrize('dir_name', ['mos_nh3'])
+    @pytest.mark.parametrize("dir_name", ["mos_nh3"])
     def test_run_update_internal_coords(self, dr_data, mo_dirpath, delete_tmp_dir):
         with temp_dir(delete_tmp_dir) as tmp_dir:
             dr_data.dr.workdir = tmp_dir
@@ -318,15 +384,19 @@ class TestDefineRunner(object):
                 # set poll to None so that kill is called and cover all cases
                 dr_data.dr.define.proc.poll.return_value = None
             assert dr_data.dr.run_update_internal_coords()
-            self.assert_sendline_has_calls(dr_data.sendline_mock, ["sy c3v ", "*", "qq"])
+            self.assert_sendline_has_calls(
+                dr_data.sendline_mock, ["sy c3v ", "*", "qq"]
+            )
             if dr_data.use_popen:
                 dr_data.dr.define.kill.assert_called_once_with(sig=signal.SIGKILL)
             else:
                 dr_data.dr.define.close.assert_called_once_with(force=True)
             self.assert_sendline_calls(dr_data.sendline_mock, dr_data.dr.sent_commands)
 
-    @pytest.mark.parametrize('dir_name', ['mos_nh3'])
-    def test_run_update_internal_coords_error(self, dr_data, mo_dirpath, delete_tmp_dir):
+    @pytest.mark.parametrize("dir_name", ["mos_nh3"])
+    def test_run_update_internal_coords_error(
+        self, dr_data, mo_dirpath, delete_tmp_dir
+    ):
         with temp_dir(delete_tmp_dir) as tmp_dir:
             dr_data.dr.workdir = tmp_dir
             dr_data.dr.parameters = {"copymo": mo_dirpath}
@@ -351,7 +421,9 @@ class TestDefineRunner(object):
                 # set poll to None so that kill is called and cover all cases
                 dr_data.dr.define.proc.poll.return_value = None
             dr_data.dr.run_generate_mo_files()
-            self.assert_sendline_calls(dr_data.sendline_mock, ["", "n", "n", "y", "eht", "y", "0", "y", "qq"])
+            self.assert_sendline_calls(
+                dr_data.sendline_mock, ["", "n", "n", "y", "eht", "y", "0", "y", "qq"]
+            )
             if dr_data.use_popen:
                 dr_data.dr.define.kill.assert_called_once_with(sig=signal.SIGKILL)
             else:
@@ -371,7 +443,10 @@ class TestDefineRunner(object):
                 # set poll to None so that kill is called and cover all cases
                 dr_data.dr.define.proc.poll.return_value = None
             dr_data.dr.run_generate_mo_files()
-            self.assert_sendline_calls(dr_data.sendline_mock, ["", "y", "sy c1 ", "*", "n", "y", "use control", "", "qq"])
+            self.assert_sendline_calls(
+                dr_data.sendline_mock,
+                ["", "y", "sy c1 ", "*", "n", "y", "use control", "", "qq"],
+            )
             if dr_data.use_popen:
                 dr_data.dr.define.kill.assert_called_once_with(sig=signal.SIGKILL)
             else:
@@ -382,7 +457,7 @@ class TestDefineRunner(object):
         assert dr_data.dr._get_bin_path() == "define"
 
     def test_set_metric(self, dr_data, delete_tmp_dir):
-        with temp_dir(delete_tmp_dir) as tmp_dir:
+        with temp_dir(delete_tmp_dir):
             # first create the control with the specified metric
             dr_data.dr.parameters = {"metric": 2}
             dr_data.dr._set_metric()
@@ -417,20 +492,31 @@ class TestDefineRunner(object):
         dr_data.dr.parameters = {"desy": True, "ired": True}
         dr_data.expect_mock.side_effect = [0, 0, 0, 0, 0]
         dr_data.dr._geometry_menu(new_coords=True)
-        self.assert_sendline_calls(dr_data.sendline_mock, ["a coord", "c", "desy", "ired"])
+        self.assert_sendline_calls(
+            dr_data.sendline_mock, ["a coord", "c", "desy", "ired"]
+        )
 
     def test_geometry_menu_new_coords_2(self, dr_data):
         dr_data.dr.parameters = {"desy": True, "ired": True, "desy_eps": 0.0001}
         dr_data.expect_mock.side_effect = [0, 1, 0, 0]
         dr_data.dr._geometry_menu(new_coords=True)
-        self.assert_sendline_calls(dr_data.sendline_mock, ["a coord", "desy 0.0001", "ired"])
+        self.assert_sendline_calls(
+            dr_data.sendline_mock, ["a coord", "desy 0.0001", "ired"]
+        )
 
     def test_geometry_menu_new_coords_3(self, dr_data):
         # here desy will be ignored
-        dr_data.dr.parameters = {"desy": True, "ired": True, "sym": "c2v", "sym_eps": 0.01}
+        dr_data.dr.parameters = {
+            "desy": True,
+            "ired": True,
+            "sym": "c2v",
+            "sym_eps": 0.01,
+        }
         dr_data.expect_mock.side_effect = [0, 1, 1, 0]
         dr_data.dr._geometry_menu(new_coords=True)
-        self.assert_sendline_calls(dr_data.sendline_mock, ["a coord", "sy c2v 0.01", "ired"])
+        self.assert_sendline_calls(
+            dr_data.sendline_mock, ["a coord", "sy c2v 0.01", "ired"]
+        )
 
     def test_geometry_menu_no_new_coords(self, dr_data):
         dr_data.dr.parameters = {"desy": False, "ired": False}
@@ -438,13 +524,19 @@ class TestDefineRunner(object):
         dr_data.dr._geometry_menu(new_coords=False, update=True)
         self.assert_sendline_calls(dr_data.sendline_mock, ["y"])
 
-    @pytest.mark.parametrize('dir_name', ['mos_nh3'])
+    @pytest.mark.parametrize("dir_name", ["mos_nh3"])
     def test_geometry_menu_copymo(self, dr_data, mo_dirpath):
-        dr_data.dr.parameters = {"desy": True, "ired": True, "sy": None,
-                              "copymo": mo_dirpath}
+        dr_data.dr.parameters = {
+            "desy": True,
+            "ired": True,
+            "sy": None,
+            "copymo": mo_dirpath,
+        }
         dr_data.expect_mock.side_effect = [0, 0, 0, 1, 0]
         dr_data.dr._geometry_menu(new_coords=True)
-        self.assert_sendline_calls(dr_data.sendline_mock, ["a coord", "c", "sy c3v ", "ired"])
+        self.assert_sendline_calls(
+            dr_data.sendline_mock, ["a coord", "c", "sy c3v ", "ired"]
+        )
 
     def test_geometry_menu_incompatibility_1(self, dr_data):
         dr_data.expect_mock.side_effect = [1]
@@ -593,10 +685,16 @@ class TestDefineRunner(object):
 
     def test_define_basis_sets(self, dr_data):
 
-        dr_data.dr.parameters = {"basis": "def2-SVP", "basis_atom": {1: "def2-SVP", "Ca": "def2-SVP"}}
+        dr_data.dr.parameters = {
+            "basis": "def2-SVP",
+            "basis_atom": {1: "def2-SVP", "Ca": "def2-SVP"},
+        }
         dr_data.expect_mock.side_effect = [0, 0, 0, 0, 0, 0]
         dr_data.dr._define_basis_sets()
-        self.assert_sendline_calls(dr_data.sendline_mock, ["b", "all def2-SVP", "b", "1 def2-SVP", "b", "\"Ca\" def2-SVP"])
+        self.assert_sendline_calls(
+            dr_data.sendline_mock,
+            ["b", "all def2-SVP", "b", "1 def2-SVP", "b", '"Ca" def2-SVP'],
+        )
 
     def test_switch_to_molecular_orbital_definition_menu(self, dr_data):
 
@@ -618,7 +716,9 @@ class TestDefineRunner(object):
             dr_data.dr.workdir = tmp_dir
             dr_data.expect_mock.side_effect = [0]
             dr_data.dr._set_mo_from_control_file()
-            self.assert_sendline_calls(dr_data.sendline_mock, ["use {}".format(control_path)])
+            self.assert_sendline_calls(
+                dr_data.sendline_mock, ["use {}".format(control_path)]
+            )
 
     def test_set_mo_from_control_file_2(self, dr_data, delete_tmp_dir):
         with temp_dir(delete_tmp_dir) as tmp_dir:
@@ -628,11 +728,13 @@ class TestDefineRunner(object):
             dr_data.dr.workdir = tmp_dir
             dr_data.expect_mock.side_effect = [4, 2]
             dr_data.dr._set_mo_from_control_file()
-            self.assert_sendline_calls(dr_data.sendline_mock, ["use {}".format(control_path), ""])
+            self.assert_sendline_calls(
+                dr_data.sendline_mock, ["use {}".format(control_path), ""]
+            )
 
     def test_set_mo_from_control_file_longpath(self, dr_data, delete_tmp_dir):
         with temp_dir(delete_tmp_dir) as tmp_dir:
-            dir_path = os.path.join(*(["extremelytoolongfilepath"]*3))
+            dir_path = os.path.join(*(["extremelytoolongfilepath"] * 3))
             makedirs_p(dir_path)
             control_path = os.path.join(tmp_dir, dir_path, "control")
             touch_file(control_path)
@@ -640,7 +742,9 @@ class TestDefineRunner(object):
             dr_data.dr.workdir = tmp_dir
             dr_data.expect_mock.side_effect = [1, 0]
             dr_data.dr._set_mo_from_control_file()
-            self.assert_sendline_calls(dr_data.sendline_mock, ["use {}".format("tmp_mo/control"), ""])
+            self.assert_sendline_calls(
+                dr_data.sendline_mock, ["use {}".format("tmp_mo/control"), ""]
+            )
 
     def test_set_mo_from_control_file_error(self, dr_data):
         with pytest.raises(DefineParameterError):
@@ -663,7 +767,9 @@ class TestDefineRunner(object):
         dr_data.dr.parameters = {"charge": 1, "unpaired_electrons": 2}
         dr_data.expect_mock.side_effect = [1, 0, 0, 0, 0, 0]
         dr_data.dr._extended_hueckel_theory_menu()
-        self.assert_sendline_calls(dr_data.sendline_mock, ["eht", "y", "1", "no", "u 2", "*"])
+        self.assert_sendline_calls(
+            dr_data.sendline_mock, ["eht", "y", "1", "no", "u 2", "*"]
+        )
 
     def test_extended_hueckel_theory_menu_error(self, dr_data):
         dr_data.dr.parameters = {"charge": 1, "unpaired_electrons": None}
@@ -701,24 +807,29 @@ class TestDefineRunner(object):
         dr_data.dr._excited_state_menu()
         self.assert_sendline_calls(dr_data.sendline_mock, ["ex", "urpa", "*", "*", "y"])
 
-
     def test_excited_state_menu_polly(self, dr_data):
         se = [match_ex_response_st_off, match_ex_response_polly_on]
         type(dr_data.dr.define).match = mock.PropertyMock(side_effect=se)
         dr_data.dr.parameters = {"ex_method": "polly", "ex_multi": "singlet"}
         dr_data.expect_mock.side_effect = [0, 0, 0, 2, 0]
         dr_data.dr._excited_state_menu()
-        self.assert_sendline_calls(dr_data.sendline_mock, ["ex", "polly", "*", "*", "y"])
+        self.assert_sendline_calls(
+            dr_data.sendline_mock, ["ex", "polly", "*", "*", "y"]
+        )
 
     def test_excited_state_menu_wrong_menu(self, dr_data):
-        type(dr_data.dr.define).match = mock.PropertyMock(return_value=match_ex_response_wrong)
+        type(dr_data.dr.define).match = mock.PropertyMock(
+            return_value=match_ex_response_wrong
+        )
         dr_data.dr.parameters = {"ex_method": "rpa", "ex_multi": "dublet"}
         dr_data.expect_mock.side_effect = [0, 0, 0, 2, 0]
         with pytest.raises(UnsupportedDefineStateError):
             dr_data.dr._excited_state_menu()
 
     def test_excited_state_menu_wrong_ex_method(self, dr_data):
-        type(dr_data.dr.define).match = mock.PropertyMock(return_value=match_ex_response_st_off)
+        type(dr_data.dr.define).match = mock.PropertyMock(
+            return_value=match_ex_response_st_off
+        )
         dr_data.dr.parameters = {"ex_method": "wrong", "ex_multi": "singlet"}
         dr_data.expect_mock.side_effect = [0, 0, 0, 2, 0]
         with pytest.raises(DefineParameterError):
@@ -733,23 +844,48 @@ class TestDefineRunner(object):
             dr_data.dr._excited_state_menu()
 
     def test_excited_state_menu_irrep(self, dr_data):
-        se = [match_ex_response_st_off, match_ex_response_rpas_on, match_ex_state_selection]
+        se = [
+            match_ex_response_st_off,
+            match_ex_response_rpas_on,
+            match_ex_state_selection,
+        ]
         type(dr_data.dr.define).match = mock.PropertyMock(side_effect=se)
         # dr_data.dr.define.match = match_ex_state_selection
         dr_data.dr.parameters = {"ex_all_states": 10, "ex_irrep_states": {"a1": 7}}
         dr_data.expect_mock.side_effect = [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]
         dr_data.dr._excited_state_menu()
-        # use has_calls here since the iteration of the states is done over a dict and the order may not
-        # be assured.
-        self.assert_sendline_has_calls(dr_data.sendline_mock,
-                                       ["ex", "rpas", "*", "a1 7", "a2 9", "b1 10", "b2 10", "a 10", "*", "*", "y"])
+        # use has_calls here since the iteration of the states is done over a dict
+        # and the order may not be assured.
+        self.assert_sendline_has_calls(
+            dr_data.sendline_mock,
+            [
+                "ex",
+                "rpas",
+                "*",
+                "a1 7",
+                "a2 9",
+                "b1 10",
+                "b2 10",
+                "a 10",
+                "*",
+                "*",
+                "y",
+            ],
+        )
 
     def test_excited_state_menu_irrep_wrong_sym(self, dr_data):
-        se = [match_ex_response_st_off, match_ex_response_rpas_on, match_ex_state_selection]
+        se = [
+            match_ex_response_st_off,
+            match_ex_response_rpas_on,
+            match_ex_state_selection,
+        ]
         type(dr_data.dr.define).match = mock.PropertyMock(side_effect=se)
         dr_data.dr.parameters = {"ex_all_states": None, "ex_irrep_states": {"z": 7}}
         dr_data.expect_mock.side_effect = [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]
-        with pytest.raises(DefineParameterError, match="No excited state could be set given the input parameters"):
+        with pytest.raises(
+            DefineParameterError,
+            match="No excited state could be set given the input parameters",
+        ):
             dr_data.dr._excited_state_menu()
 
     def test_excited_state_menu_frequency(self, dr_data):
@@ -758,7 +894,10 @@ class TestDefineRunner(object):
         dr_data.dr.parameters = {"ex_frequency": 100}
         dr_data.expect_mock.side_effect = [0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0]
         dr_data.dr._excited_state_menu()
-        self.assert_sendline_calls(dr_data.sendline_mock, ["ex", "rpas", "*", "nm", "a", "100", "*", "*", "*", "y"])
+        self.assert_sendline_calls(
+            dr_data.sendline_mock,
+            ["ex", "rpas", "*", "nm", "a", "100", "*", "*", "*", "y"],
+        )
 
     def test_set_ri_state(self, dr_data):
         dr_data.dr.parameters = {"rijk": True}
@@ -776,7 +915,9 @@ class TestDefineRunner(object):
         dr_data.dr.parameters = {"gridsize": "m3", "functional": "pbe"}
         dr_data.expect_mock.side_effect = [0, 0, 0, 0, 0]
         dr_data.dr._set_dft_options(use_dft=True)
-        self.assert_sendline_calls(dr_data.sendline_mock, ["dft", "on", "func pbe", "grid m3", ""])
+        self.assert_sendline_calls(
+            dr_data.sendline_mock, ["dft", "on", "func pbe", "grid m3", ""]
+        )
 
     def test_set_dft_options_wrong_xc(self, dr_data):
         dr_data.dr.parameters = {"gridsize": "m3", "functional": "pbexxxx"}
@@ -792,49 +933,136 @@ class TestDefineRunner(object):
 
     def test_set_mp2_options(self, dr_data):
 
-        dr_data.dr.parameters = {"maxcor": 300, "ex_mp2": {}, "use_f12": False, "use_f12*": False, "maxiter": 200}
+        dr_data.dr.parameters = {
+            "maxcor": 300,
+            "ex_mp2": {},
+            "use_f12": False,
+            "use_f12*": False,
+            "maxiter": 200,
+        }
         dr_data.expect_mock.side_effect = [0, 0, 0, 0, 0, 0, 0, 0]
         dr_data.dr._set_mp2_options(energy_only=True, method="mp2")
-        self.assert_sendline_calls(dr_data.sendline_mock,
-                                   ["cc", "freeze", "*", "cbas", "*", "memory", "300", "ricc2", "mp2",
-                                    "maxiter 200", "*", "*"])
+        self.assert_sendline_calls(
+            dr_data.sendline_mock,
+            [
+                "cc",
+                "freeze",
+                "*",
+                "cbas",
+                "*",
+                "memory",
+                "300",
+                "ricc2",
+                "mp2",
+                "maxiter 200",
+                "*",
+                "*",
+            ],
+        )
 
     def test_set_mp2_options_geoopt(self, dr_data):
-        dr_data.dr.parameters = {"maxcor": 300, "ex_mp2": {}, "use_f12": False, "use_f12*": False, "maxiter": 200}
+        dr_data.dr.parameters = {
+            "maxcor": 300,
+            "ex_mp2": {},
+            "use_f12": False,
+            "use_f12*": False,
+            "maxiter": 200,
+        }
         dr_data.expect_mock.side_effect = [0, 0, 0, 0, 0, 0, 0, 0]
         dr_data.dr._set_mp2_options(energy_only=False, method="mp2")
-        self.assert_sendline_calls(dr_data.sendline_mock,
-                                   ["cc", "freeze", "*", "cbas", "*", "memory", "300", "ricc2", "geoopt mp2",
-                                    "maxiter 200", "*", "*"])
+        self.assert_sendline_calls(
+            dr_data.sendline_mock,
+            [
+                "cc",
+                "freeze",
+                "*",
+                "cbas",
+                "*",
+                "memory",
+                "300",
+                "ricc2",
+                "geoopt mp2",
+                "maxiter 200",
+                "*",
+                "*",
+            ],
+        )
 
     def test_set_mp2_options_mp2(self, dr_data):
-        dr_data.dr.parameters = {"maxcor": None, "ex_mp2": {"a1": [10, 1]},
-                                 "use_f12": False, "use_f12*": False, "maxiter": None}
+        dr_data.dr.parameters = {
+            "maxcor": None,
+            "ex_mp2": {"a1": [10, 1]},
+            "use_f12": False,
+            "use_f12*": False,
+            "maxiter": None,
+        }
         dr_data.expect_mock.side_effect = [0, 0, 0, 0, 0, 3, 0, 0, 0]
         dr_data.dr._set_mp2_options(energy_only=True, method="adc(2)")
-        self.assert_sendline_calls(dr_data.sendline_mock,
-                                   ["cc", "freeze", "*", "cbas", "*", "exci", "irrep=a1 multiplicity=10 nexc=1",
-                                    "spectrum  states=all", "exprop  states=all unrelaxed", "*", "ricc2", "adc(2)",
-                                    "*", "*"])
+        self.assert_sendline_calls(
+            dr_data.sendline_mock,
+            [
+                "cc",
+                "freeze",
+                "*",
+                "cbas",
+                "*",
+                "exci",
+                "irrep=a1 multiplicity=10 nexc=1",
+                "spectrum  states=all",
+                "exprop  states=all unrelaxed",
+                "*",
+                "ricc2",
+                "adc(2)",
+                "*",
+                "*",
+            ],
+        )
 
     def test_set_mp2_options_mp2_error(self, dr_data):
         # fail due at ex_mp2
-        dr_data.dr.parameters = {"maxcor": None, "ex_mp2": {"a1": [10, 1]},
-                                 "use_f12": False, "use_f12*": False, "maxiter": None}
+        dr_data.dr.parameters = {
+            "maxcor": None,
+            "ex_mp2": {"a1": [10, 1]},
+            "use_f12": False,
+            "use_f12*": False,
+            "maxiter": None,
+        }
         dr_data.expect_mock.side_effect = [0, 0, 0, 0, 0, 0, 0, 0, 0]
         with pytest.raises(DefineParameterError):
             dr_data.dr._set_mp2_options(energy_only=True, method="adc(2)")
 
     def test_set_mp2_options_f12(self, dr_data, delete_tmp_dir):
-        with temp_dir(delete_tmp_dir) as tmp_dir:
+        with temp_dir(delete_tmp_dir):
             c = Control.empty()
             c.to_file("control")
-            dr_data.dr.parameters = {"maxcor": None, "ex_mp2": {}, "use_f12": True, "use_f12*": True, "maxiter": None,
-                                     "method": "ccsdt"}
+            dr_data.dr.parameters = {
+                "maxcor": None,
+                "ex_mp2": {},
+                "use_f12": True,
+                "use_f12*": True,
+                "maxiter": None,
+                "method": "ccsdt",
+            }
             dr_data.expect_mock.side_effect = [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]
             dr_data.dr._set_mp2_options(energy_only=True, method="ccsd(t)")
-            self.assert_sendline_calls(dr_data.sendline_mock, ["cc", "freeze", "*", "cbas", "*", "f12",
-                                                               "*", "cabs", "*", "ricc2", "ccsd(t)","*", "*"])
+            self.assert_sendline_calls(
+                dr_data.sendline_mock,
+                [
+                    "cc",
+                    "freeze",
+                    "*",
+                    "cbas",
+                    "*",
+                    "f12",
+                    "*",
+                    "cabs",
+                    "*",
+                    "ricc2",
+                    "ccsd(t)",
+                    "*",
+                    "*",
+                ],
+            )
             c = Control.from_file("control")
             assert c.sdgo("rir12", "ccsdapprox").strip() == "ccsd(f12*)"
 
@@ -849,14 +1077,16 @@ class TestDefineRunner(object):
         dr_data.dr.parameters = {"scfconv": 0.0001, "scfiterlimit": 100}
         dr_data.expect_mock.side_effect = [0, 0, 0, 0, 0, 0]
         dr_data.dr._set_scf_options()
-        self.assert_sendline_calls(dr_data.sendline_mock, ["scf", "conv", "0.0001", "iter", "100", ""])
+        self.assert_sendline_calls(
+            dr_data.sendline_mock, ["scf", "conv", "0.0001", "iter", "100", ""]
+        )
 
     def test_quit_general_menu(self, dr_data):
 
         dr_data.dr._quit_general_menu()
         self.assert_sendline_calls(dr_data.sendline_mock, ["*"])
 
-    @pytest.mark.parametrize('dir_name', ['mos_nh3'])
+    @pytest.mark.parametrize("dir_name", ["mos_nh3"])
     def test_copy_mo_files_mo(self, dr_data, mo_dirpath, delete_tmp_dir):
         with temp_dir(delete_tmp_dir) as tmp_dir:
             dr_data.dr.parameters = {"copymo": mo_dirpath}
@@ -868,7 +1098,7 @@ class TestDefineRunner(object):
                 assert len(s) > 10
             assert not os.path.isfile("alpha")
 
-    @pytest.mark.parametrize('dir_name', ['alpha_beta_nh3'])
+    @pytest.mark.parametrize("dir_name", ["alpha_beta_nh3"])
     def test_copy_mo_files_alpha_beta(self, dr_data, mo_dirpath, delete_tmp_dir):
         with temp_dir(delete_tmp_dir) as tmp_dir:
             dr_data.dr.parameters = {"copymo": mo_dirpath}
@@ -881,7 +1111,7 @@ class TestDefineRunner(object):
                 assert len(s) > 10
             assert not os.path.isfile("mos")
 
-    @pytest.mark.parametrize('dir_name', ['mos_nh3'])
+    @pytest.mark.parametrize("dir_name", ["mos_nh3"])
     def test_copy_mo_files_ab_mos(self, dr_data, mo_dirpath, delete_tmp_dir):
         with temp_dir(delete_tmp_dir) as tmp_dir:
             dr_data.dr.parameters = {"copymo": mo_dirpath}
@@ -902,12 +1132,19 @@ class TestDefineRunner(object):
                 dr_data.dr._copy_mo_files()
 
     def test_add_cosmo(self, dr_data, delete_tmp_dir):
-        with temp_dir(delete_tmp_dir) as tmp_dir:
+        with temp_dir(delete_tmp_dir):
             with open("control", "w") as f:
                 f.write("$end")
 
-            dr_data.dr.parameters = {"epsilon": 0.1, "nppa": 1, "nspa": 1, "disex": 0.1, "rsolv": 0.1,
-                                     "routf": 0.1, "cavity": "closed"}
+            dr_data.dr.parameters = {
+                "epsilon": 0.1,
+                "nppa": 1,
+                "nspa": 1,
+                "disex": 0.1,
+                "rsolv": 0.1,
+                "routf": 0.1,
+                "cavity": "closed",
+            }
             dr_data.dr._add_cosmo()
 
             with open("control") as f:
@@ -922,19 +1159,41 @@ class TestDefineRunner(object):
 
     def test_dump_command_file(self, delete_tmp_dir):
         dr = DefineRunner({})
-        dr.sent_commands = ['', 'dscf', 'a coord', 'desy', 'ired', '*', 'b', 'all def-SV(P)', '*',
-                            'eht', 'y', '0', 'y', 'dft', 'on', 'func b-p', '', 'scf', 'iter', '200', '', '*']
+        dr.sent_commands = [
+            "",
+            "dscf",
+            "a coord",
+            "desy",
+            "ired",
+            "*",
+            "b",
+            "all def-SV(P)",
+            "*",
+            "eht",
+            "y",
+            "0",
+            "y",
+            "dft",
+            "on",
+            "func b-p",
+            "",
+            "scf",
+            "iter",
+            "200",
+            "",
+            "*",
+        ]
 
-        with temp_dir(delete_tmp_dir) as tmp_dir:
+        with temp_dir(delete_tmp_dir):
             dr.dump_command_file(filepath="test_file")
             with open("test_file") as f:
                 lines = f.readlines()
-            commands = [l.strip() for l in lines]
+            commands = [line.strip() for line in lines]
 
             assert dr.sent_commands == commands
 
     def test_postprocess(self, dr_data, delete_tmp_dir):
-        with temp_dir(delete_tmp_dir) as tmp_dir:
+        with temp_dir(delete_tmp_dir):
             dr_data.dr.parameters = {"disp": "DFT-D3", "use_cosmo": True}
 
             with open("control", "w") as f:
